import requests
import xml.etree.ElementTree as ET
from util.getters import get_connected_sim, get_sims_info


def connect_sim(mssb_ip, mssb_serial, 
                repos_dir, mssb_file_dir, 
                sim_plmn, slot_terminal, 
                sims_config=None, sim_imsi=None):
    """
    This method connects the desired SIM having that PLMN to the provided slot/terminal
    :param repos_dir: Your repository directory
    :param mssb_file_dir: The directory with the mssb file
    :param sim_plmn: PLMN of the desired SIM Card
    :param slot_terminal: slot_terminal: MSSB terminal ID port assigned to the slot
    :param sims_config: dict containing the sims_config
    :param sim_imsi: IMSI for the specific SIM Card to be connected
    :return: returns whether the operation succeeded or not
    :rtype: bool
    """
    if sims_config:
        sims = sims_config
    else:
        sims = get_sims_info(repos_dir, mssb_serial, mssb_file_dir)
    sim_mssb = 0
    for i in range(0, len(sims)):
        if sim_plmn == sims[i].get('DEV_CUSTOM_2'):
            if sim_imsi:
                if sim_imsi == sims[i].get('DEV_CUSTOM_1'):
                    sim_mssb = sims[i].get('ID')
            else:
                sim_mssb = sims[i].get('ID')
            break
    response = requests.get('http://' + mssb_ip + '/rest.php?'
                                                     'command=connect'
                                                     '&sim='+str(sim_mssb)+
                                                     '&terminal='+str(slot_terminal)+
                                                     '&mssbSerial=' + mssb_serial)
    response_xml = ET.fromstring(response.content)
    sim_success_value = response_xml.find('params').find("success").text
    connected = get_connected_sim(mssb_ip, mssb_serial, int(slot_terminal)).get('custom_2') == sim_plmn
    return sim_success_value == "1" and connected



from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

VERSION = '1.0.3' 
DESCRIPTION = 'Python package to be used with Matrix SIM Switch Box tool'

long_description = (here / 'README.rst').read_text(encoding='utf-8')

# Setting up
setup(
        name="mssbox", 
        version=VERSION,
        author="Antonio Carlos",
        author_email="antoniocarlos048@gmail.com",
        description=DESCRIPTION,
        long_description=long_description,
        long_description_content_type='text/x-rst',
        license='MIT',
        url="https://github.com/acarlos94/MSSB_python_package",
        packages=find_packages(),
        python_requires='>=3',
        install_requires=[], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        
        keywords=['python', 'mssb', 'matrixssb', 'mssbox'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS",
            "Operating System :: Microsoft :: Windows",
            "Operating System :: Unix"
        ]
)



import requests
import json
import xml.etree.ElementTree as ET


def get_connected_sim(mssb_ip, mssb_serial, slot_terminal):
    """
    This method returns the SIM Card allocated to the provided slot
    :param slot_terminal: int MSSB terminal port assigned to the slot
    :return: returns a dict with SIM attribs (id, name, custom_1 (IMSI), custom_2 (PLMN)
    """
    sim = get_all_connected_sims(mssb_ip, mssb_serial).get(int(slot_terminal))
    return sim


def get_all_connected_sims(mssb_ip, mssb_serial):
    """
    This method returns all SIMs connected to terminals
    :return: A dict with all SIMs with their attribs (id, name, custom_1 (IMSI), custom_2 (PLMN)
    """
    response = requests.get(f"http://{mssb_ip}/rest.php?command=listcon&mssbSerial={mssb_serial}")                                                 
    response_xml = ET.fromstring(response.content)
    connections = response_xml.find('connections').findall("terminal")
    sims = dict()
    for i in range(0, len(connections)):
        sims[i] = connections[i].find("sim")
    return sims


def get_sims_info(repos_dir, mssb_serial, mssb_file_dir):
    """
    This function gets the info for the SIMs connected to the MSSB via file exported from MSSB
    :param repos_dir: Your repository directory
    :param mssb_serial: Serial for the MSSB
    :param mssb_file_dir: The directory with the mssb file
    :return: dict with the SIMs Config
    """
    file = f"{repos_dir}/{mssb_serial}_sims.json"
    mssb_file = f"{mssb_file_dir}/{mssb_serial}"
    with open(file, 'wb') as f:
        f.write(mssb_file.content)
    with open(file) as json_file:
        data = json.load(json_file)
    return data

    


import requests
import xml.etree.ElementTree as ET
from util.getters import get_connected_sim


def disconnect_sim(mssb_ip, mssb_serial, slot_terminal):
    """
    This method disconnects any SIM attached to the specified terminal/slot
    :param slot_terminal: MSSB terminal ID port assigned to the slot
    :return: returns whether the operation succeeded or not
    :rtype: bool
    """
    if get_connected_sim(mssb_ip, mssb_serial, int(slot_terminal)).get('id') == "":
        return True
    response = requests.get(f"http://{mssb_ip}/rest.php?command=disconnect&sim=0&terminal={str(slot_terminal)}&mssbSerial={mssb_serial}")
    response_xml = ET.fromstring(response.content)
    sim_success_value = response_xml.find('params').find("success").text
    return sim_success_value == "1" and get_connected_sim(int(slot_terminal)).get('id') == ""



import requests
import xml.etree.ElementTree as ET 


def reset_all_connections(mssb_ip, mssb_serial):  # PAY ATTENTION! THIS METHOD IMPACTS ALL DEVICES CONNECTED TO THE MSSB
    """
    This method disconnects all SIMs connected to any terminals
    :return: returns the result of the request, 'true' or 'false
    :rtype: bool
    """
    response = requests.get(f"http://{mssb_ip}/rest.php?command=resetall&mssbSerial={mssb_serial}")
    response_xml = ET.fromstring(response.content)
    success_value = response_xml.find('params').find("success").text
    return bool(success_value)
